==> webkitgtk-1.10.0.tar.xz: webkitgtk-1.10.0/Source/WebCore/html/DOMURL.h <==
/*
 * Copyright (C) 2011 Google Inc. All rights reserved.
 * Copyright (C) 2012 Motorola Mobility Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DOMURL_h
#define DOMURL_h

#include "KURL.h"
#include "PlatformString.h"
#include <wtf/HashSet.h>
#include <wtf/PassRefPtr.h>
#include <wtf/RefCounted.h>

namespace WebCore {

class Blob;
class MediaSource;
class MediaStream;
class ScriptExecutionContext;

class DOMURL : public RefCounted<DOMURL> {

public:
    static PassRefPtr<DOMURL> create() { return adoptRef(new DOMURL); }

#if ENABLE(BLOB)
    static void contextDestroyed(ScriptExecutionContext*);

    static String createObjectURL(ScriptExecutionContext*, Blob*);
    static void revokeObjectURL(ScriptExecutionContext*, const String&);
#if ENABLE(MEDIA_SOURCE)
    static String createObjectURL(ScriptExecutionContext*, MediaSource*);
#endif
#if ENABLE(MEDIA_STREAM)
    static String createObjectURL(ScriptExecutionContext*, MediaStream*);
#endif
#endif
};

} // namespace WebCore

#endif // DOMURL_h

==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/html/DOMURL.h <==
/*
 * Copyright (C) 2011 Google Inc. All rights reserved.
 * Copyright (C) 2012 Motorola Mobility Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DOMURL_h
#define DOMURL_h

#include "ExceptionCode.h"
#include "URL.h"
#include "URLUtils.h"
#include <wtf/HashSet.h>
#include <wtf/PassRefPtr.h>
#include <wtf/RefCounted.h>
#include <wtf/text/WTFString.h>

namespace WebCore {

class Blob;
class ScriptExecutionContext;
class URLRegistrable;

class DOMURL : public RefCounted<DOMURL>, public URLUtils<DOMURL> {

public:
    static PassRefPtr<DOMURL> create(const String& url, const String& base, ExceptionCode&);
    static PassRefPtr<DOMURL> create(const String& url, const DOMURL* base, ExceptionCode&);
    static PassRefPtr<DOMURL> create(const String& url, ExceptionCode&);

    URL href() const { return m_url; }
    void setHref(const String& url);
    void setHref(const String&, ExceptionCode&);

    static String createObjectURL(ScriptExecutionContext*, Blob*);
    static void revokeObjectURL(ScriptExecutionContext*, const String&);

    static String createPublicURL(ScriptExecutionContext*, URLRegistrable*);

private:
    DOMURL(const String& url, const String& base, ExceptionCode&);
    DOMURL(const String& url, const DOMURL& base, ExceptionCode&);
    DOMURL(const String& url, ExceptionCode&);

    URL m_baseURL;
    URL m_url;
};

} // namespace WebCore

#endif // DOMURL_h
